pub trait BlockExecutionWriter: NodePrimitivesProvider + BlockWriterwhere
Self::Primitives: NodePrimitives<Block = Self::Block>,{
// Required methods
fn take_block_and_execution_above(
&self,
block: u64,
) -> Result<Chain<Self::Primitives>, ProviderError>;
fn remove_block_and_execution_above(
&self,
block: u64,
) -> Result<(), ProviderError>;
}Expand description
BlockExecution Writer
Required Methods
Sourcefn take_block_and_execution_above(
&self,
block: u64,
) -> Result<Chain<Self::Primitives>, ProviderError>
fn take_block_and_execution_above( &self, block: u64, ) -> Result<Chain<Self::Primitives>, ProviderError>
Take all of the blocks above the provided number and their execution result
The passed block number will stay in the database.
Sourcefn remove_block_and_execution_above(
&self,
block: u64,
) -> Result<(), ProviderError>
fn remove_block_and_execution_above( &self, block: u64, ) -> Result<(), ProviderError>
Remove all of the blocks above the provided number and their execution result
The passed block number will stay in the database.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".