StageCheckpointReader

Trait StageCheckpointReader 

pub trait StageCheckpointReader: Send {
    // Required methods
    fn get_stage_checkpoint(
        &self,
        id: StageId,
    ) -> Result<Option<StageCheckpoint>, ProviderError>;
    fn get_stage_checkpoint_progress(
        &self,
        id: StageId,
    ) -> Result<Option<Vec<u8>>, ProviderError>;
    fn get_all_checkpoints(
        &self,
    ) -> Result<Vec<(String, StageCheckpoint)>, ProviderError>;
}
The trait for fetching stage checkpoint related data.

Required Methods

fn get_stage_checkpoint( &self, id: StageId, ) -> Result<Option<StageCheckpoint>, ProviderError>

Fetch the checkpoint for the given stage.

fn get_stage_checkpoint_progress( &self, id: StageId, ) -> Result<Option<Vec<u8>>, ProviderError>

Get stage checkpoint progress.

fn get_all_checkpoints( &self, ) -> Result<Vec<(String, StageCheckpoint)>, ProviderError>

Reads all stage checkpoints and returns a list with the name of the stage and the checkpoint data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T> StageCheckpointReader for &'a T

Source

impl<T> StageCheckpointReader for Arc<T>

Implementors

Source

impl<C, N> StageCheckpointReader for NoopProvider<C, N>
where C: Send + Sync, N: NodePrimitives,

Source

impl<N: ProviderNodeTypes> StageCheckpointReader for BlockchainProvider<N>

Source

impl<N: ProviderNodeTypes> StageCheckpointReader for ProviderFactory<N>

Source

impl<T: NodePrimitives, ChainSpec: Send + Sync> StageCheckpointReader for MockEthProvider<T, ChainSpec>

Available on crate features test-utils only.
Source

impl<TX: DbTx, N: NodeTypes> StageCheckpointReader for DatabaseProvider<TX, N>